# awssso

Simple adaptation (datetime parsing) of:

https://www.matscloud.com/blog/2020/06/25/how-to-use-aws-cdk-with-aws-sso-profiles/


You will need:

AWS CLI 2+
BOTO3

## How to use

``` bash
awssso {aws-config-profile}
```

``` bash
awssso {aws-config-profile} {custom-cert-profile-name}
```